@@ -26,9 +26,9 @@ build_time_vars = {'ABIFLAGS': '',
  'CC': 'gcc',
  'CCSHARED': '-fPIC',
  'CFLAGS': '-fno-strict-overflow -Wsign-compare '
-           '-DDYNAMIC_ANNOTATIONS_ENABLED=1 -DNDEBUG -fcf-protection '
-           '-fexceptions -fcf-protection -fexceptions -fcf-protection '
-           '-fexceptions',
+           '-DDYNAMIC_ANNOTATIONS_ENABLED=1 -DNDEBUG -fexceptions '
+           '-fcf-protection -fexceptions -fcf-protection -fexceptions '
+           '-fcf-protection   -O3',
  'CFLAGSFORSHARED': '-fPIC',
  'CFLAGS_ALIASING': '',
  'CODECS_COMMON_HEADERS': '/builddir/build/BUILD/Python-3.12.4/Modules/cjkcodecs/multibytecodec.h '
@@ -36,10 +36,10 @@ build_time_vars = {'ABIFLAGS': '',
  'COMPILEALL_OPTS': '-j0',
  'CONFIGFILES': 'configure configure.ac acconfig.h pyconfig.h.in '
                 'Makefile.pre.in',
- 'CONFIGURE_CFLAGS': '-fcf-protection -fexceptions',
- 'CONFIGURE_CFLAGS_NODIST': '-O2 -flto=auto -ffat-lto-objects -fexceptions -g '
+ 'CONFIGURE_CFLAGS': '-fexceptions -fcf-protection',
+ 'CONFIGURE_CFLAGS_NODIST': '-flto=auto -ffat-lto-objects -fexceptions -g '
                             '-grecord-gcc-switches -pipe -Wall '
-                            '-Werror=format-security '
+                            '-Wno-complain-wrong-lang -Werror=format-security '
                             '-Wp,-U_FORTIFY_SOURCE,-D_FORTIFY_SOURCE=3 '
                             '-Wp,-D_GLIBCXX_ASSERTIONS '
                             '-specs=/usr/lib/rpm/redhat/redhat-hardened-cc1 '
@@ -92,7 +92,7 @@ build_time_vars = {'ABIFLAGS': '',
                 "'build_alias=x86_64-redhat-linux-gnu' "
                 "'host_alias=x86_64-redhat-linux-gnu' "
                 "'PKG_CONFIG_PATH=:/usr/lib64/pkgconfig:/usr/share/pkgconfig' "
-                "'CC=gcc' 'CFLAGS=-fcf-protection -fexceptions  ' 'LDFLAGS= ' "
+                "'CC=gcc' 'CFLAGS=-fexceptions -fcf-protection  ' 'LDFLAGS= ' "
                 "'CPPFLAGS='",
  'CONFINCLUDEDIR': '/usr/include',
  'CONFINCLUDEPY': '/usr/include/python3.12',
@@ -673,11 +673,11 @@ build_time_vars = {'ABIFLAGS': '',
  'LIBDIR': '/usr/lib64',
  'LIBEXPAT_A': 'Modules/expat/libexpat.a',
  'LIBEXPAT_CFLAGS': '-fno-strict-overflow -Wsign-compare '
-                    '-DDYNAMIC_ANNOTATIONS_ENABLED=1 -DNDEBUG -fcf-protection '
-                    '-fexceptions -fcf-protection -fexceptions -fcf-protection '
-                    '-fexceptions -O2 -flto=auto -ffat-lto-objects '
+                    '-DDYNAMIC_ANNOTATIONS_ENABLED=1 -DNDEBUG -fexceptions '
+                    '-fcf-protection -fexceptions -fcf-protection -fexceptions '
+                    '-fcf-protection   -O3 -flto=auto -ffat-lto-objects '
                     '-fexceptions -g -grecord-gcc-switches -pipe -Wall '
-                    '-Werror=format-security '
+                    '-Wno-complain-wrong-lang -Werror=format-security '
                     '-Wp,-U_FORTIFY_SOURCE,-D_FORTIFY_SOURCE=3 '
                     '-Wp,-D_GLIBCXX_ASSERTIONS '
                     '-specs=/usr/lib/rpm/redhat/redhat-hardened-cc1 '
@@ -691,9 +691,9 @@ build_time_vars = {'ABIFLAGS': '',
                     '-flto-partition=none -g -std=c11 -Wextra '
                     '-Wno-unused-parameter -Wno-missing-field-initializers '
                     '-Wstrict-prototypes -Werror=implicit-function-declaration '
-                    '-fvisibility=hidden -O2 -flto=auto -ffat-lto-objects '
+                    '-fvisibility=hidden -flto=auto -ffat-lto-objects '
                     '-fexceptions -g -grecord-gcc-switches -pipe -Wall '
-                    '-Werror=format-security '
+                    '-Wno-complain-wrong-lang -Werror=format-security '
                     '-Wp,-U_FORTIFY_SOURCE,-D_FORTIFY_SOURCE=3 '
                     '-Wp,-D_GLIBCXX_ASSERTIONS '
                     '-specs=/usr/lib/rpm/redhat/redhat-hardened-cc1 '
@@ -702,7 +702,7 @@ build_time_vars = {'ABIFLAGS': '',
                     '-march=x86-64-v3 -mtune=generic '
                     '-fasynchronous-unwind-tables -fstack-clash-protection '
                     '-fcf-protection -mtls-dialect=gnu2    -D_GNU_SOURCE -fPIC '
-                    '-fwrapv  -fprofile-use -fprofile-correction '
+                    '-fwrapv -O3 -fprofile-use -fprofile-correction '
                     '-I/builddir/build/BUILD/Python-3.12.4/Include/internal '
                     '-IObjects -IInclude -IPython -I. '
                     '-I/builddir/build/BUILD/Python-3.12.4/Include -fPIC -fPIC',
@@ -711,10 +711,11 @@ build_time_vars = {'ABIFLAGS': '',
  'LIBHACL_CFLAGS': '-I/builddir/build/BUILD/Python-3.12.4/Modules/_hacl/include '
                    '-D_BSD_SOURCE -D_DEFAULT_SOURCE -fno-strict-overflow '
                    '-Wsign-compare -DDYNAMIC_ANNOTATIONS_ENABLED=1 -DNDEBUG '
-                   '-fcf-protection -fexceptions -fcf-protection -fexceptions '
-                   '-fcf-protection -fexceptions -O2 -flto=auto '
+                   '-fexceptions -fcf-protection -fexceptions -fcf-protection '
+                   '-fexceptions -fcf-protection   -O3 -flto=auto '
                    '-ffat-lto-objects -fexceptions -g -grecord-gcc-switches '
-                   '-pipe -Wall -Werror=format-security '
+                   '-pipe -Wall -Wno-complain-wrong-lang '
+                   '-Werror=format-security '
                    '-Wp,-U_FORTIFY_SOURCE,-D_FORTIFY_SOURCE=3 '
                    '-Wp,-D_GLIBCXX_ASSERTIONS '
                    '-specs=/usr/lib/rpm/redhat/redhat-hardened-cc1 '
@@ -728,8 +729,9 @@ build_time_vars = {'ABIFLAGS': '',
                    '-g -std=c11 -Wextra -Wno-unused-parameter '
                    '-Wno-missing-field-initializers -Wstrict-prototypes '
                    '-Werror=implicit-function-declaration -fvisibility=hidden '
-                   '-O2 -flto=auto -ffat-lto-objects -fexceptions -g '
-                   '-grecord-gcc-switches -pipe -Wall -Werror=format-security '
+                   '-flto=auto -ffat-lto-objects -fexceptions -g '
+                   '-grecord-gcc-switches -pipe -Wall -Wno-complain-wrong-lang '
+                   '-Werror=format-security '
                    '-Wp,-U_FORTIFY_SOURCE,-D_FORTIFY_SOURCE=3 '
                    '-Wp,-D_GLIBCXX_ASSERTIONS '
                    '-specs=/usr/lib/rpm/redhat/redhat-hardened-cc1 '
@@ -738,7 +740,7 @@ build_time_vars = {'ABIFLAGS': '',
                    '-march=x86-64-v3 -mtune=generic '
                    '-fasynchronous-unwind-tables -fstack-clash-protection '
                    '-fcf-protection -mtls-dialect=gnu2    -D_GNU_SOURCE -fPIC '
-                   '-fwrapv  -fprofile-use -fprofile-correction '
+                   '-fwrapv -O3 -fprofile-use -fprofile-correction '
                    '-I/builddir/build/BUILD/Python-3.12.4/Include/internal '
                    '-IObjects -IInclude -IPython -I. '
                    '-I/builddir/build/BUILD/Python-3.12.4/Include -fPIC -fPIC',
@@ -750,11 +752,11 @@ build_time_vars = {'ABIFLAGS': '',
  'LIBMPDEC_A': 'Modules/_decimal/libmpdec/libmpdec.a',
  'LIBMPDEC_CFLAGS': '-DCONFIG_64=1 -DANSI=1 -DHAVE_UINT128_T=1 '
                     '-fno-strict-overflow -Wsign-compare '
-                    '-DDYNAMIC_ANNOTATIONS_ENABLED=1 -DNDEBUG -fcf-protection '
-                    '-fexceptions -fcf-protection -fexceptions -fcf-protection '
-                    '-fexceptions -O2 -flto=auto -ffat-lto-objects '
+                    '-DDYNAMIC_ANNOTATIONS_ENABLED=1 -DNDEBUG -fexceptions '
+                    '-fcf-protection -fexceptions -fcf-protection -fexceptions '
+                    '-fcf-protection   -O3 -flto=auto -ffat-lto-objects '
                     '-fexceptions -g -grecord-gcc-switches -pipe -Wall '
-                    '-Werror=format-security '
+                    '-Wno-complain-wrong-lang -Werror=format-security '
                     '-Wp,-U_FORTIFY_SOURCE,-D_FORTIFY_SOURCE=3 '
                     '-Wp,-D_GLIBCXX_ASSERTIONS '
                     '-specs=/usr/lib/rpm/redhat/redhat-hardened-cc1 '
@@ -768,9 +770,9 @@ build_time_vars = {'ABIFLAGS': '',
                     '-flto-partition=none -g -std=c11 -Wextra '
                     '-Wno-unused-parameter -Wno-missing-field-initializers '
                     '-Wstrict-prototypes -Werror=implicit-function-declaration '
-                    '-fvisibility=hidden -O2 -flto=auto -ffat-lto-objects '
+                    '-fvisibility=hidden -flto=auto -ffat-lto-objects '
                     '-fexceptions -g -grecord-gcc-switches -pipe -Wall '
-                    '-Werror=format-security '
+                    '-Wno-complain-wrong-lang -Werror=format-security '
                     '-Wp,-U_FORTIFY_SOURCE,-D_FORTIFY_SOURCE=3 '
                     '-Wp,-D_GLIBCXX_ASSERTIONS '
                     '-specs=/usr/lib/rpm/redhat/redhat-hardened-cc1 '
@@ -779,7 +781,7 @@ build_time_vars = {'ABIFLAGS': '',
                     '-march=x86-64-v3 -mtune=generic '
                     '-fasynchronous-unwind-tables -fstack-clash-protection '
                     '-fcf-protection -mtls-dialect=gnu2    -D_GNU_SOURCE -fPIC '
-                    '-fwrapv  -fprofile-use -fprofile-correction '
+                    '-fwrapv -O3 -fprofile-use -fprofile-correction '
                     '-I/builddir/build/BUILD/Python-3.12.4/Include/internal '
                     '-IObjects -IInclude -IPython -I. '
                     '-I/builddir/build/BUILD/Python-3.12.4/Include -fPIC -fPIC',
@@ -1113,7 +1115,7 @@ build_time_vars = {'ABIFLAGS': '',
  'MVWDELCH_IS_EXPRESSION': 1,
  'NO_AS_NEEDED': '-Wl,--no-as-needed',
  'OBJECT_OBJS': '\\',
- 'OPT': '-DDYNAMIC_ANNOTATIONS_ENABLED=1 -DNDEBUG -fcf-protection -fexceptions',
+ 'OPT': '-DDYNAMIC_ANNOTATIONS_ENABLED=1 -DNDEBUG -fexceptions -fcf-protection',
  'PACKAGE_BUGREPORT': 0,
  'PACKAGE_NAME': 0,
  'PACKAGE_STRING': 0,
@@ -1149,11 +1151,11 @@ build_time_vars = {'ABIFLAGS': '',
  'PY_BUILTIN_HASHLIB_HASHES': '"blake2"',
  'PY_BUILTIN_MODULE_CFLAGS': '-fno-strict-overflow -Wsign-compare '
                              '-DDYNAMIC_ANNOTATIONS_ENABLED=1 -DNDEBUG '
-                             '-fcf-protection -fexceptions -fcf-protection '
-                             '-fexceptions -fcf-protection -fexceptions -O2 '
-                             '-flto=auto -ffat-lto-objects -fexceptions -g '
+                             '-fexceptions -fcf-protection -fexceptions '
+                             '-fcf-protection -fexceptions -fcf-protection   '
+                             '-O3 -flto=auto -ffat-lto-objects -fexceptions -g '
                              '-grecord-gcc-switches -pipe -Wall '
-                             '-Werror=format-security '
+                             '-Wno-complain-wrong-lang -Werror=format-security '
                              '-Wp,-U_FORTIFY_SOURCE,-D_FORTIFY_SOURCE=3 '
                              '-Wp,-D_GLIBCXX_ASSERTIONS '
                              '-specs=/usr/lib/rpm/redhat/redhat-hardened-cc1 '
@@ -1170,9 +1172,9 @@ build_time_vars = {'ABIFLAGS': '',
                              '-Wno-missing-field-initializers '
                              '-Wstrict-prototypes '
                              '-Werror=implicit-function-declaration '
-                             '-fvisibility=hidden -O2 -flto=auto '
-                             '-ffat-lto-objects -fexceptions -g '
-                             '-grecord-gcc-switches -pipe -Wall '
+                             '-fvisibility=hidden -flto=auto -ffat-lto-objects '
+                             '-fexceptions -g -grecord-gcc-switches -pipe '
+                             '-Wall -Wno-complain-wrong-lang '
                              '-Werror=format-security '
                              '-Wp,-U_FORTIFY_SOURCE,-D_FORTIFY_SOURCE=3 '
                              '-Wp,-D_GLIBCXX_ASSERTIONS '
@@ -1183,18 +1185,18 @@ build_time_vars = {'ABIFLAGS': '',
                              '-fasynchronous-unwind-tables '
                              '-fstack-clash-protection -fcf-protection '
                              '-mtls-dialect=gnu2    -D_GNU_SOURCE -fPIC '
-                             '-fwrapv  -fprofile-use -fprofile-correction '
+                             '-fwrapv -O3 -fprofile-use -fprofile-correction '
                              '-I/builddir/build/BUILD/Python-3.12.4/Include/internal '
                              '-IObjects -IInclude -IPython -I. '
                              '-I/builddir/build/BUILD/Python-3.12.4/Include '
                              '-fPIC -DPy_BUILD_CORE_BUILTIN',
  'PY_CFLAGS': '-fno-strict-overflow -Wsign-compare '
-              '-DDYNAMIC_ANNOTATIONS_ENABLED=1 -DNDEBUG -fcf-protection '
-              '-fexceptions -fcf-protection -fexceptions -fcf-protection '
-              '-fexceptions',
- 'PY_CFLAGS_NODIST': '-O2 -flto=auto -ffat-lto-objects -fexceptions -g '
+              '-DDYNAMIC_ANNOTATIONS_ENABLED=1 -DNDEBUG -fexceptions '
+              '-fcf-protection -fexceptions -fcf-protection -fexceptions '
+              '-fcf-protection   -O3',
+ 'PY_CFLAGS_NODIST': '-flto=auto -ffat-lto-objects -fexceptions -g '
                      '-grecord-gcc-switches -pipe -Wall '
-                     '-Werror=format-security '
+                     '-Wno-complain-wrong-lang -Werror=format-security '
                      '-Wp,-U_FORTIFY_SOURCE,-D_FORTIFY_SOURCE=3 '
                      '-Wp,-D_GLIBCXX_ASSERTIONS '
                      '-specs=/usr/lib/rpm/redhat/redhat-hardened-cc1 '
@@ -1209,9 +1211,9 @@ build_time_vars = {'ABIFLAGS': '',
                      '-Wno-unused-parameter -Wno-missing-field-initializers '
                      '-Wstrict-prototypes '
                      '-Werror=implicit-function-declaration '
-                     '-fvisibility=hidden -O2 -flto=auto -ffat-lto-objects '
+                     '-fvisibility=hidden -flto=auto -ffat-lto-objects '
                      '-fexceptions -g -grecord-gcc-switches -pipe -Wall '
-                     '-Werror=format-security '
+                     '-Wno-complain-wrong-lang -Werror=format-security '
                      '-Wp,-U_FORTIFY_SOURCE,-D_FORTIFY_SOURCE=3 '
                      '-Wp,-D_GLIBCXX_ASSERTIONS '
                      '-specs=/usr/lib/rpm/redhat/redhat-hardened-cc1 '
@@ -1220,15 +1222,15 @@ build_time_vars = {'ABIFLAGS': '',
                      '-march=x86-64-v3 -mtune=generic '
                      '-fasynchronous-unwind-tables -fstack-clash-protection '
                      '-fcf-protection -mtls-dialect=gnu2    -D_GNU_SOURCE '
-                     '-fPIC -fwrapv  -fprofile-use -fprofile-correction '
+                     '-fPIC -fwrapv -O3 -fprofile-use -fprofile-correction '
                      '-I/builddir/build/BUILD/Python-3.12.4/Include/internal',
  'PY_COERCE_C_LOCALE': 1,
  'PY_CORE_CFLAGS': '-fno-strict-overflow -Wsign-compare '
-                   '-DDYNAMIC_ANNOTATIONS_ENABLED=1 -DNDEBUG -fcf-protection '
-                   '-fexceptions -fcf-protection -fexceptions -fcf-protection '
-                   '-fexceptions -O2 -flto=auto -ffat-lto-objects -fexceptions '
-                   '-g -grecord-gcc-switches -pipe -Wall '
-                   '-Werror=format-security '
+                   '-DDYNAMIC_ANNOTATIONS_ENABLED=1 -DNDEBUG -fexceptions '
+                   '-fcf-protection -fexceptions -fcf-protection -fexceptions '
+                   '-fcf-protection   -O3 -flto=auto -ffat-lto-objects '
+                   '-fexceptions -g -grecord-gcc-switches -pipe -Wall '
+                   '-Wno-complain-wrong-lang -Werror=format-security '
                    '-Wp,-U_FORTIFY_SOURCE,-D_FORTIFY_SOURCE=3 '
                    '-Wp,-D_GLIBCXX_ASSERTIONS '
                    '-specs=/usr/lib/rpm/redhat/redhat-hardened-cc1 '
@@ -1242,8 +1244,9 @@ build_time_vars = {'ABIFLAGS': '',
                    '-g -std=c11 -Wextra -Wno-unused-parameter '
                    '-Wno-missing-field-initializers -Wstrict-prototypes '
                    '-Werror=implicit-function-declaration -fvisibility=hidden '
-                   '-O2 -flto=auto -ffat-lto-objects -fexceptions -g '
-                   '-grecord-gcc-switches -pipe -Wall -Werror=format-security '
+                   '-flto=auto -ffat-lto-objects -fexceptions -g '
+                   '-grecord-gcc-switches -pipe -Wall -Wno-complain-wrong-lang '
+                   '-Werror=format-security '
                    '-Wp,-U_FORTIFY_SOURCE,-D_FORTIFY_SOURCE=3 '
                    '-Wp,-D_GLIBCXX_ASSERTIONS '
                    '-specs=/usr/lib/rpm/redhat/redhat-hardened-cc1 '
@@ -1252,7 +1255,7 @@ build_time_vars = {'ABIFLAGS': '',
                    '-march=x86-64-v3 -mtune=generic '
                    '-fasynchronous-unwind-tables -fstack-clash-protection '
                    '-fcf-protection -mtls-dialect=gnu2    -D_GNU_SOURCE -fPIC '
-                   '-fwrapv  -fprofile-use -fprofile-correction '
+                   '-fwrapv -O3 -fprofile-use -fprofile-correction '
                    '-I/builddir/build/BUILD/Python-3.12.4/Include/internal '
                    '-IObjects -IInclude -IPython -I. '
                    '-I/builddir/build/BUILD/Python-3.12.4/Include -fPIC '
@@ -1298,12 +1301,12 @@ build_time_vars = {'ABIFLAGS': '',
  'PY_SSL_DEFAULT_CIPHERS': 2,
  'PY_SSL_DEFAULT_CIPHER_STRING': 0,
  'PY_STDMODULE_CFLAGS': '-fno-strict-overflow -Wsign-compare '
-                        '-DDYNAMIC_ANNOTATIONS_ENABLED=1 -DNDEBUG '
+                        '-DDYNAMIC_ANNOTATIONS_ENABLED=1 -DNDEBUG -fexceptions '
                         '-fcf-protection -fexceptions -fcf-protection '
-                        '-fexceptions -fcf-protection -fexceptions -O2 '
-                        '-flto=auto -ffat-lto-objects -fexceptions -g '
+                        '-fexceptions -fcf-protection   -O3 -flto=auto '
+                        '-ffat-lto-objects -fexceptions -g '
                         '-grecord-gcc-switches -pipe -Wall '
-                        '-Werror=format-security '
+                        '-Wno-complain-wrong-lang -Werror=format-security '
                         '-Wp,-U_FORTIFY_SOURCE,-D_FORTIFY_SOURCE=3 '
                         '-Wp,-D_GLIBCXX_ASSERTIONS '
                         '-specs=/usr/lib/rpm/redhat/redhat-hardened-cc1 '
@@ -1318,9 +1321,9 @@ build_time_vars = {'ABIFLAGS': '',
                         '-Wno-unused-parameter -Wno-missing-field-initializers '
                         '-Wstrict-prototypes '
                         '-Werror=implicit-function-declaration '
-                        '-fvisibility=hidden -O2 -flto=auto -ffat-lto-objects '
+                        '-fvisibility=hidden -flto=auto -ffat-lto-objects '
                         '-fexceptions -g -grecord-gcc-switches -pipe -Wall '
-                        '-Werror=format-security '
+                        '-Wno-complain-wrong-lang -Werror=format-security '
                         '-Wp,-U_FORTIFY_SOURCE,-D_FORTIFY_SOURCE=3 '
                         '-Wp,-D_GLIBCXX_ASSERTIONS '
                         '-specs=/usr/lib/rpm/redhat/redhat-hardened-cc1 '
@@ -1329,7 +1332,7 @@ build_time_vars = {'ABIFLAGS': '',
                         '-march=x86-64-v3 -mtune=generic '
                         '-fasynchronous-unwind-tables -fstack-clash-protection '
                         '-fcf-protection -mtls-dialect=gnu2    -D_GNU_SOURCE '
-                        '-fPIC -fwrapv  -fprofile-use -fprofile-correction '
+                        '-fPIC -fwrapv -O3 -fprofile-use -fprofile-correction '
                         '-I/builddir/build/BUILD/Python-3.12.4/Include/internal '
                         '-IObjects -IInclude -IPython -I. '
                         '-I/builddir/build/BUILD/Python-3.12.4/Include -fPIC',
